%--------------------------------------------------------------------------
% File     : COL006=StrongFxdPtSK-3 : TPTP v1.1.2. Bugfixed v1.0.0.
% Domain   : Combinatory Logic
% Problem  : Strong fixed point for S and K
% Version  : [Wos & McCune, 1988] (equality) axioms.
%            Theorem formulation : The fixed point is provided and 
%            checked.
% English  : The strong fixed point property holds for the set 
%            P consisting of the combinators B and W alone, where ((Bx)y)z 
%            = x(yz), (Wx)y = (xy)y.

% Refs     : Wos L., McCune W.W (1988), Challenge Problems Focusing 
%            on Equality and Combinatory Logic: Evaluating Automated 
%            Theorem-Proving Programs, Proceedings of the 9th 
%            International Conference on Automated Deduction (Argonne, IL, 
%            1988), (Lecture Notes in Computer Science, 310), 714-729.
% Source   : [Wos & McCune, 1988]
% Names    : C6 [Wos & McCune, 1988]

% Status   : 
% Syntax   : Number of clauses           :    9 (   0 non-Horn)(   4 unit)
%            Number of literals          :   15 (  13 equality)
%            Number of predicate symbols :    2 (   0 propositional)
%            Number of function symbols  :    4 (   3 constant)
%            Number of variables         :   18 (   1 singleton)
%            Maximal clause size         :    3
%            Maximal term depth          :    8

% Comments : fixed_point/1 substitution axioms are not included 
%            as it is simply a way of introducing the required copies 
%            of the strong fixed point.
%--------------------------------------------------------------------------
%----Include the axioms of equality 
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(s_definition,axiom,
    [++equal(apply(apply(apply(s,X),Y),Z),apply(apply(X,Z),apply(Y,Z)))]).

input_clause(k_definition,axiom,
    [++equal(apply(apply(k,X),Y),X)]).

input_clause(apply_substitution1,axiom,
    [--equal(A,B),
     ++equal(apply(A,C),apply(B,C))]).

input_clause(apply_substitution2,axiom,
    [--equal(D,E),
     ++equal(apply(F,D),apply(F,E))]).

input_clause(strong_fixed_point,axiom,
    [--equal(apply(Strong_fixed_point,fixed_pt),apply(fixed_pt,apply(
Strong_fixed_point,fixed_pt))),
     ++fixed_point(Strong_fixed_point)]).

input_clause(prove_strong_fixed_point,theorem,
    [--fixed_point(apply(apply(s,apply(k,apply(apply(s,apply(apply(s,k),k)),
apply(apply(s,k),k)))),apply(apply(s,apply(apply(s,apply(k,s)),k)),apply(k,
apply(apply(s,apply(apply(s,k),k)),apply(apply(s,k),k))))))]).
%--------------------------------------------------------------------------
